import sys
import os

from bwikibot.api import Wiki
from bwikibot.ui import shift_block
from bwikibot import translator

SESSION_FILE = 'cli.session'

def get_wiki():
    wiki = Wiki('', throttle=0)
    wiki.session_file(SESSION_FILE)
    return wiki

def read_page(*args):
    ''' Print page which's name passed in param to stdout '''
    name = ' '.join(args).strip()
    if not name:
        print('Pass page name as last param')
        return
    wiki = get_wiki()
    print(wiki.page(name).read())

def autocomplete(*args):
    ''' Print list of page names which starts from passed prefix '''
    prefix = ' '.join(args)
    wiki = get_wiki()
    print('\n'.join(
        wiki.opensearch(prefix)
    ))

def login(*args):
    ''' Login to site with domain passed in param '''
    url = ' '.join(args).strip()
    if not url:
        print('you should pass domain like uk.wikipedia.org')
        return
    wiki = Wiki('http://%s/w/api.php' % url, throttle=0)
    wiki.session_file(SESSION_FILE)

def change_endpoint(*args):
    ''' Change endpoing but don't change cookies (for wiki families) '''
    url = ' '.join(args)
    wiki = Wiki('', throttle=0)
    wiki.session_file(SESSION_FILE)
    wiki.endpoint = 'http://%s/w/api.php' % url
    wiki.save(SESSION_FILE)

def logout(ignored_param):
    ''' Delete session file '''
    os.remove(SESSION_FILE)

def write_page(*args):
    ''' Read text from stdio and save to page with name passed in param '''
    name = ' '.join(args)
    wiki = get_wiki()

    text = []
    for line in sys.stdin:
        text.append(line)

    wiki.page(name).write(''.join(text), 'cli editing')

actions = {
    'read': read_page,
    'autocomplete': autocomplete,
    'login': login,
    'endpoint': change_endpoint,
    'logout': logout,
    'write': write_page,
    'translate': translator.main,
}

def run(*argv):
    if len(argv) < 2:
        print('You should pass action:')
        for action, function in actions.items():
            print('{:15s} - {}'.format(
                action,
                shift_block(function.__doc__, 20)
            ))
        return

    actions[argv[1]](*argv[2:])

def main():
    run(*sys.argv)

if __name__=="__main__":
    main()



import re

re_infobox_begin = re.compile(r'\s*\{\{[Ii]nfobox\s+film\s*')
re_infobox_end = re.compile(r'\s*\}\}\s*')
re_infobox_field = re.compile(r'\s*\|\s*([\w_]+)\s*=\s*(.+)')
def get_infobox_data(text):
    lines = text.splitlines()
    data = {}
    in_infobox = False
    for line in lines:
        if re_infobox_begin.match(line):
            in_infobox = True
            continue
        if in_infobox:
            match = re_infobox_field.match(line)
            if match:
                print(match.groups())
                #data[match.group(1)] = match.group(2)
                continue
            else:
                print('Cannot parse template param line')
                print(line)
            if re_infobox_end.match(line):
                return data
    return data


def run_test(text):
    print(get_infobox_data(text))

test = r"""
{{Infobox film
| name           = Team America: World Police
| image          = Team america poster 300px.jpg
| image_size     = 215px
| alt            = 
| caption        = Theatrical release poster
| director       = [[Trey Parker]]
| producer       = [[Trey Parker]]<br>[[Matt Stone]]<br>[[Scott Rudin]]
| writer         = Trey Parker<br />Matt Stone<br />Pam Brady
| starring       = Trey Parker<br />Matt Stone<br />[[Kristen Miller]]<br />[[Masasa Moyo|Masasa]]<br />[[Daran Norris]]<br />[[Phil Hendrie]]<br />[[Maurice LaMarche]]
| music          = [[Harry Gregson-Williams]]
| cinematography = [[Bill Pope]]
| editing        = Tom Vogt
| studio         = [[Scott Rudin|Scott Rudin Productions]]
| distributor    = [[Paramount Pictures]]
| released       = {{Film date|2004|10|14|[[Denver Film Festival|Denver]]|2004|10|15}}
| runtime        = 98 minutes
| country        = United States
| language       = English
| budget         = $32 million
| gross          = $50,907,422
}}
'''''Team America: World Police''''' is a 2004 [[Satire|satirical]] [[Action film#Action comedy|action comedy film]] written by [[Trey Parker]], [[Matt Stone]], and [[Pam Brady]] and directed by Parker, all of whom are also known for the popular animated television series ''[[South Park]]''. The film is a [[satire]] of big-budget [[action film]]s and their associated [[cliché]]s and [[stereotype]]s, with particular humorous emphasis on the global implications of [[Politics of the United States|US politics]]. The title of the film itself is derived from domestic and international political criticisms that the U.S. frequently and unilaterally tries to "[[American foreign policy|police the world]]". The film features a cast composed of [[marionette]]s. ''Team America'' focuses on a fictional team of political [[paramilitary]] policemen known as "Team America: World Police", who attempt to save the world from a violent terrorist plot led by [[Kim Jong-il]]. 

==External links==
{{wikiquote}}
* {{Official website|http://www.teamamerica.com}}
* {{IMDb title|0372588|Team America: World Police}}
* {{Bcdb|68495-Team_America_World_Police|Team America: World Police}}
* {{AllRovi movie|309182|Team America: World Police}}
* {{mojo title|teamamerica|Team America: World Police}}
* {{rotten-tomatoes|team_america_world_police|Team America: World Police}}
* [http://flakmag.com/film/teamamerica.html An analysis at Flakmagazine]
* [http://rogerebert.suntimes.com/apps/pbcs.dll/article?AID=/20041014/REVIEWS/40921007/1023 Roger Ebert's review]

{{Trey Parker and Matt Stone}}
{{Scott Rudin}}
{{Empire Award for Best Comedy}}
{{DEFAULTSORT:Team America - World Police}}
[[Category:2004 films]]
[[Category:2000s action films]]
[[Category:2000s adventure films]]
[[Category:2000s comedy films]]
[[Category:American films]]
"""

if __name__=='__main__':
    run_test(test)



'''
User interface utilities
'''

def print_diff(text_a, text_b):
    ''' Print difference between two values '''
    a_lines = text_a.splitlines(1)
    b_lines = text_b.splitlines(1)
    diff = ndiff(a_lines, b_lines)

    for line in diff:
        print('\033[%sm%s\033[0m' % ({
            '-':91,
            '+':92,
            '?':94,
        }.get(line[0], 0), line[:-1]))

def ask_y_n(question):
    while True:
        ans = input(question)
        if ans.lower() == 'y':
            return True
        if ans.lower() == 'n':
            return False
        if not ans.strip():
            return ''
        print('дозволені тільки відповіді y/n та порожня')


def shift_block(block, spaces):
    ''' shifts lines of block of text to right '''
    lines = block.splitlines()
    lines = [' ' * spaces + line.strip() for line in lines]
    return '\n'.join(lines).strip()
